#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R31 on 2026-02-21 14:49:57.443389

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.

"""
import inspect

from pycatia.hybrid_shape_interfaces.plane import Plane
from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.real_param import RealParam


class HybridShapePlaneBetween(Plane):
    """

    Introduced in V5-6R2022.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2026-02-21 14:49:57.443389)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         CATGSMIDLItf.Plane
                |                             HybridShapePlaneBetween


    """

    def __init__(self, com_object):
        super().__init__(com_object)

        self.release_check(
            self.application.system_configuration.release,
            32,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        self.com_object = com_object

    @property
    def first_element(self) -> Reference:
        """

        Introduced in V5-6R2022.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2026-02-21 14:49:57.443389)
                | Property FirstElement() As Reference
                |     Returns or sets the first reference Plane.
                |     Sub-element(s) supported (see Boundary object): Vertex.
                |
                |     Example:
                |         This example retrieves in RefPlane1 the first reference Plane for the
                |         PlaneBetween hybrid shape feature.
                |
                |          Dim RefPlane1 As Reference
                |          Set RefPlane1 = PlaneBetween.FirstPlane

        :rtype: Reference
        """

        self.release_check(
            self.application.system_configuration.release,
            32,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return Reference(self.com_object.FirstElement)

    @first_element.setter
    def first_element(self, value: Reference):
        """
        :param Reference value:
        """

        self.release_check(
            self.application.system_configuration.release,
            32,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        self.com_object.FirstElement = value

    @property
    def orientation(self) -> int:
        """
        Introduced in V5-6R2022.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2026-02-21 14:49:57.443389)
                | Property Orientation() As long
                |     Returns or sets the orientation. Role:
                |     Orientation = 1 means that distance is measured from the second Plane
                |
                |     Example:
                |         This example retrieves in Orient the orientation for the PlaneBetween
                |         hybrid shape feature.
                |
                |          Dim Orient As long
                |          Set Orient = PlaneBetween.Orientation

        :rtype: int
        """

        self.release_check(
            self.application.system_configuration.release,
            32,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return self.com_object.Orientation

    @orientation.setter
    def orientation(self, value: int):
        """
        :param int value:
        """

        self.release_check(
            self.application.system_configuration.release,
            32,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        self.com_object.Orientation = value

    @property
    def ratio(self) -> RealParam:
        """
        Introduced in V5-6R2022.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2026-02-21 14:49:57.443389)
                | Property Ratio() As RealParam (Read Only)
                |     Get the ratio. Role:
                |     if d1 is the distance between the first Plane and the created Plane, and d2 is the distance between the first Plane and the second Plane, then ratio = d1/d2.
                |
                |     Example:
                |         This example retrieves in ratio the orientation for the PlaneBetween
                |         hybrid shape feature.
                |
                |          Dim ratio  As CATIARealParam
                |          Get ratio = PlaneBetween.Ratio

        :rtype: RealParam
        """

        self.release_check(
            self.application.system_configuration.release,
            32,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return RealParam(self.com_object.Ratio)

    @property
    def second_element(self) -> Reference:
        """

        Introduced in V5-6R2022.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2026-02-21 14:49:57.443389)
                | Property SecondElement() As Reference
                |     Returns or sets the second reference Plane.
                |     Sub-element(s) supported (see Boundary object): Vertex.
                |
                |     Example:
                |         This example retrieves in RefPlane2 the second reference Plane for the
                |         PlaneBetween hybrid shape feature.
                |
                |          Dim RefPlane2 As Reference
                |          Set RefPlane2 = PlaneBetween.SecondPlane

        :rtype: Reference
        """

        self.release_check(
            self.application.system_configuration.release,
            32,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return Reference(self.com_object.SecondElement)

    @second_element.setter
    def second_element(self, value: Reference):
        """
        :param Reference value:
        """

        self.release_check(
            self.application.system_configuration.release,
            32,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        self.com_object.SecondElement = value

    def __repr__(self):
        return f'HybridShapePlaneBetween(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R31 on 2024-08-20 16:04:57.203445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.

"""
import inspect

from pycatia.in_interfaces.references import References
from pycatia.system_interfaces.any_object import AnyObject


class PartServices(AnyObject):
    """

    Introduced in V5-6R2021.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PartServices
                |
                | The object exposes services for the part.
                |
                | This object is available thanks to Part Set myPart = CATIA.ActiveDocument.Part ' Get Service Object by querying on part - extension of CATIA Base Set partServices = myPart.GetItem("CATPartServices")
                |
                | Example:
                |
                |    Set part1 = CATIA.ActiveDocument.Part
                |    Set partServices1 = myPart.GetItem("CATPartServices")

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.part_services = com_object

    def get_near_sub_elements(
            self,
            i_object: AnyObject,
            i_sub_element_dimension: int,
            i_near_object: AnyObject
    ) -> References:
        """

        Introduced in V5-6R2021.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Func GetNearSubElements(AnyObject iObject,long iSubElementDimension,AnyObject
                | iNearObject) As References
                |     Get the sub elements of a geometric object or a body that are the closest
                |     to a geometric object or a body.
                |
                |     Parameters:
                |
                |         iObject
                |             A geometric object or a body
                |         iSubElementDimension
                |             The dimension of sub elements wanted: 0 for vertex, 1 for edge, 2
                |             for face.
                |         iNearObject
                |             A geometric object or a body to be close to
                |         oSubElements
                |             List of the sub elements of iObject (without duplicates) closest to
                |             iNearObject.
                |
                |             Example:
                |                 The following example returns the vertices of a pad that are
                |                 the closest to a point.
                |
                |                   Set part1 = CATIA.ActiveDocument.Part
                |                   Set bodies1 = part1.Bodies
                |                   Set body1 = bodies1.Item("PartBody")
                |                   Set shapes1 = body1.Shapes
                |                   Set pad1 = shapes1.Item("Pad.1")
                |                   Set point1 = shapes1.Item("Point.1")
                |                   Set partServices1 = myPart.GetItem("CATPartServices")
                |                   Set references1 = partServices1.GetSubNearElements(pad1, 0, point1)

        :param AnyObject i_object:
        :param int i_sub_element_dimension:
        :param AnyObject i_near_object:
        :rtype: References
        """

        self.release_check(
            self.application.system_configuration.release,
            31,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return References(
            self.part_services.GetNearSubElements(
                i_object.com_object,
                i_sub_element_dimension,
                i_near_object.com_object
            )
        )

    def get_sub_elements(self, i_object: AnyObject, i_sub_element_dimension: int, i_duplicates: bool) -> References:
        """

        Introduced in V5-6R2021.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Func GetSubElements(AnyObject iObject,long iSubElementDimension,boolean
                | iDuplicates) As References
                |     Get the sub elements of a geometric object or a body.
                |
                |     Parameters:
                |
                |         iObject
                |             A geometric object or a body
                |         iSubElementDimension
                |             The dimension of sub elements wanted: 0 for vertex, 1 for edge, 2
                |             for face.
                |         iDuplicates
                |             Allow duplicate sub elements in the list. FALSE will remove
                |             duplicates (same label and selecting feature).
                |         oSubElements
                |             List of the sub elements
                |
                |             Example:
                |                 The following example returns the vertices of a
                |                 pad
                |
                |                   Set part1 = CATIA.ActiveDocument.Part
                |                   Set bodies1 = part1.Bodies
                |                   Set body1 = bodies1.Item("PartBody")
                |                   Set shapes1 = body1.Shapes
                |                   Set pad1 = shapes1.Item("Pad.1")
                |                   Set partServices1 = myPart.GetItem("CATPartServices")
                |                   Set references1 = partServices1.GetSubElements(pad1, 0, True)

        :param AnyObject i_object:
        :param int i_sub_element_dimension:
        :param bool i_duplicates:
        :rtype: References
        """

        self.release_check(
            self.application.system_configuration.release,
            31,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return References(self.part_services.GetSubElements(i_object.com_object, i_sub_element_dimension, i_duplicates))

    def __repr__(self):
        return f'PartServices(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R31 on 2024-08-20 16:04:57.203445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.

"""
import inspect

from pycatia.cat_tps_interfaces.semantic_gdt_common_zone import SemanticGDTCommonZone
from pycatia.system_interfaces.any_object import AnyObject


class SemanticGDTNxDisplay(AnyObject):
    """

    Introduced in V5-6R2019.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SemanticGDTNxDisplay
                |
                | Interface to distinguish Collection of features from Separate features
                | GDT.

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.semantic_gdt_nx_display = com_object

    @property
    def instance_count(self) -> int:
        """

        Introduced in V5-6R2019.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Property InstanceCount() As long (Read Only)
                |     Gets count of instances.

        :rtype: int
        """

        self.release_check(
            self.application.system_configuration.release,
            29,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return self.semantic_gdt_nx_display.InstanceCount

    def common_zone(self) -> SemanticGDTCommonZone:
        """

        Introduced in V5-6R2019.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Func CommonZone() As SemanticGDTCommonZone
                |     Gets the GDT on the Common Zone interface to access CZ modifier
                |     information. Method is only returning a valid object if ISO Standard is
                |     applied.
                |
                |     Parameters:
                |
                |         oCommonZone
                |             Common Zone related information.

        :rtype: SemanticGDTCommonZone
        """

        self.release_check(
            self.application.system_configuration.release,
            29,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return SemanticGDTCommonZone(self.semantic_gdt_nx_display.CommonZone())

    def is_a_collection(self) -> bool:
        """

        Introduced in V5-6R2019.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Func IsACollection() As boolean
                |     Checks if GDT is Collection of Features. In ISO Standard, GDT may have a CZ
                |     modifier on tolerance value.
                |
                |     Parameters:
                |
                |         oIsColl
                |
                |                 TRUE: The GDT is applied on several elements considered as a
                |                 collection
                |                 FALSE: The GDT is not applied with a collection consideration.
                |                 It must be a separate.

        :rtype: bool
        """

        self.release_check(
            self.application.system_configuration.release,
            29,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return self.semantic_gdt_nx_display.IsACollection()

    def is_a_separate(self) -> bool:
        """

        Introduced in V5-6R2019.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Func IsASeparate() As boolean
                |     Checks if GDT is Separate Features. In ASME Standard this is indicated with
                |     the "INDIVIDUALLY" text linked to the GDT.
                |
                |     Parameters:
                |
                |         oIsSeparate
                |
                |                 TRUE: The GDT is applied on several elements as many separate
                |                 specifications.
                |                 FALSE: The GDT is not applied with a separate consideration. It
                |                 must be a collection.

        :rtype: bool
        """

        self.release_check(
            self.application.system_configuration.release,
            29,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return self.semantic_gdt_nx_display.IsASeparate()

    def __repr__(self):
        return f'SemanticGdtNxDisplay(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R31 on 2024-08-20 16:04:57.203445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.

"""
import inspect

from pycatia.drafting_interfaces.drawing_coord_dim import DrawingCoordDim
from pycatia.system_interfaces.any_object import AnyObject


class CoordDim(AnyObject):
    """

    Introduced in V5-6R2018.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CoordDim


    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.coord_dim = com_object

    def get_2d_annot(self) -> DrawingCoordDim:
        """

        Introduced in V5-6R2018.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Func Get2dAnnot() As DrawingCoordDim
                |     Retrieves Drafting Coordinate dimension.

        :rtype: DrawingCoordDim
        """

        self.release_check(
            self.application.system_configuration.release,
            28,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )
        return DrawingCoordDim(self.coord_dim.Get2dAnnot())

    def __repr__(self):
        return f'CoordDim(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R31 on 2024-08-20 16:04:57.203445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.

"""
import inspect

from pycatia.drafting_interfaces.drawing_leaders import DrawingLeaders
from pycatia.drafting_interfaces.drawing_text_properties import DrawingTextProperties
from pycatia.drafting_interfaces.drawing_text_range import DrawingTextRange
from pycatia.system_interfaces.any_object import AnyObject


class DrawingGDT(AnyObject):
    """

    Introduced in V5-6R2018.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DrawingGDT
                |
                | Represents a drawing GDT in a drawing view.

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.drawing_gdt = com_object

    @property
    def angle(self) -> float:
        """

        Introduced in V5-6R2018.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Property Angle() As double
                |     Returns or sets the angle of the drawing GDT. The angle is measured between
                |     the axis system of the drawing view and the local axis system of the drawing
                |     GDT. The angle is measured in radians and is counted
                |     counterclockwise.
                |
                |     Example:
                |         This example sets the angle of the MyGDT drawing GDT to 90 degrees
                |         clockwise. You first need to compute the angle in degrees and set the minus
                |         sign to indicate the rotation is clockwise.
                |
                |          Angle90Clockwise = -90
                |          MyGDT.Angle = Angle90Clockwise

        :rtype: float
        """

        self.release_check(
            self.application.system_configuration.release,
            28,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return self.drawing_gdt.Angle

    @angle.setter
    def angle(self, value: float):
        """
        :param float value:
        """

        self.drawing_gdt.Angle = value

    @property
    def leaders(self) -> DrawingLeaders:
        """

        Introduced in V5-6R2018.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Property Leaders() As DrawingLeaders (Read Only)
                |     Returns the drawing leader collection of the drawing GDT.
                |
                |     Example:
                |         This example retrieves in LeaderCollection the collection of leaders of
                |         the MyGDT drawing GDT.
                |
                |          Dim LeaderCollection As DrawingLeaders
                |          Set LeaderCollection = MyGDT.Leaders

        :rtype: DrawingLeaders
        """

        self.release_check(
            self.application.system_configuration.release,
            28,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return DrawingLeaders(self.drawing_gdt.Leaders)

    @property
    def row_number(self) -> int:
        """

        Introduced in V5-6R2018.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Property RowNumber() As long (Read Only)
                |     Returns the number of lines in the GDT
                |
                |     Returns:
                |         The number of line in the GDT
                |
                |         Example:
                |             This example retrieves in rowNumber the row number of the MyGDT
                |             drawing GDT
                |
                |              rowNumber = MyGDT.RowNumber

        :rtype: int
        """

        self.release_check(
            self.application.system_configuration.release,
            28,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return self.drawing_gdt.RowNumber

    @property
    def text_properties(self) -> DrawingTextProperties:
        """

        Introduced in V5-6R2018.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Property TextProperties() As DrawingTextProperties (Read Only)
                |     Returns the text properties of the drawing GDT.
                |
                |     Example:
                |         This example retrieves in TextProperties the text properties of the
                |         MyGDT drawing GDT..
                |
                |          Dim TextProperties As DrawingTextProperties
                |          Set TextProperties = MyGDT.TextProperties

        :rtype: DrawingTextProperties
        """

        self.release_check(
            self.application.system_configuration.release,
            28,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return DrawingTextProperties(self.drawing_gdt.TextProperties)

    @property
    def x(self) -> float:
        """

        Introduced in V5-6R2018.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Property x() As double
                |     Returns or sets the x coordinate of the drawing GDT. It is expressed with
                |     respect to the current view coordinate system. This coordinate, like any
                |     length, is measured in millimeters.
                |
                |     Example:
                |         This example retrieves in X the x coordinate of the MyGDT drawing
                |         GDT.
                |
                |          X = MyGDT.x

        :rtype: float
        """

        self.release_check(
            self.application.system_configuration.release,
            28,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return self.drawing_gdt.x

    @x.setter
    def x(self, value: float):
        """
        :param float value:
        """

        self.drawing_gdt.x = value

    @property
    def y(self) -> float:
        """

        Introduced in V5-6R2018.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Property y() As double
                |     Returns or sets the y coordinate of the drawing GDT. It is expressed with
                |     respect to the current view coordinate system. This coordinate, like any
                |     length, is measured in millimeters.
                |
                |     Example:
                |         This example sets the y coordinate of the MyGDT drawing GDT to 5
                |         inches. You need first to convert the 5 inches into
                |         millmeters.
                |
                |          NewYCoordinate = 5*25.4/1000
                |          MyGDT.y = NewYCoordinate

        :rtype: float
        """

        self.release_check(
            self.application.system_configuration.release,
            28,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return self.drawing_gdt.y

    @y.setter
    def y(self, value: float):
        """
        :param float value:
        """

        self.drawing_gdt.y = value

    def get_reference_number(self, i_row_number: int) -> int:
        """

        Introduced in V5-6R2018.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Func GetReferenceNumber(long iRowNumber) As long
                |     Returns the number of references in a row of the GDT.
                |
                |     Parameters:
                |
                |         iRowNumber
                |             The number of the row to analyse.
                |
                |     Returns:
                |         The number of references in this row.
                |
                |         Example:
                |             This example gets the reference number of the MyGDT drawing
                |             GDT
                |
                |              MyGDT.GetReferenceNumber(iRowNumber, oRefNumber)

        :param int i_row_number:
        :rtype: int
        """

        self.release_check(
            self.application.system_configuration.release,
            28,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return self.drawing_gdt.GetReferenceNumber(i_row_number)

    def get_text_range(self, i_row_number: int, i_number: int) -> DrawingTextRange:
        """

        Introduced in V5-6R2018.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Func GetTextRange(long iRowNumber,long iNumber) As
                | DrawingTextRange
                |     Returns the CATIADrawingTextRange of tolerance value and reference
                |     value.
                |
                |     Parameters:
                |
                |         iRowNumber
                |             The number of the row to analyse If iRowNumber equals 0 to analyse
                |             upper text or lower text. If iRowNumber is greater than 0 analyse tolerance
                |             value or reference value.
                |         iNumber
                |             The modifier to analyse in this row:
                |             If iRowNumber equals 0 and iNumber = 0 represent upper text
                |             If iRowNumber equals 0 and iNumber = 1 represent lower text
                |             If iRowNumber is greater than 0 and iNumber equals 0 to analyse tolerance value
                |             If iRowNumber is greater than 0 and iNumber is greater than 0 to analyse reference value.
                |
                |     Returns:
                |         The CATIADrawingTextRange which is specified. If there is no textrange
                |         which is corresponded above, then NULL is given back.
                |         This example gets the TextRange on the specified line and modifier of
                |         the MyGDT drawing GDT
                |
                |          MyGDT.GetTextRange(iRowNumber, iNumber, oTextRange)

        :param int i_row_number:
        :param int i_number:
        :rtype: DrawingTextRange
        """

        self.release_check(
            self.application.system_configuration.release,
            28,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return DrawingTextRange(self.drawing_gdt.GetTextRange(i_row_number, i_number))

    def get_tolerance_type(self, i_row_number: int) -> int:
        """

        Introduced in V5-6R2018.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Func GetToleranceType(long iRowNumber) As long
                |     Returns the symbol used in the row of the GDT.
                |
                |     Parameters:
                |
                |         iRowNumber
                |             The number of the row to analyze.
                |
                |     Returns:
                |         The symbol in this row.
                |         0 : No GDT symbol. The specified row will be remove
                |         1 : Straightness GDT symbol
                |         2 : Flatness GDT symbol
                |         3 : Circularity GDT symbol
                |         4 : Cilindricity GDT symbol
                |         5 : Line profile GDT symbol
                |         6 : Surface profile GDT symbol
                |         7 : Angularity GDT symbol
                |         8 : Perpendicularity GDT symbol
                |         9 : Parallelism GDT symbol
                |         10 : Position GDT symbol
                |         11 : Concentricity GDT symbol
                |         12 : Symmetry
                |         13 : Circular runout GDT symbol
                |         14 : Total runout GDT symbol
                |
                |         Example:
                |             This example gets the symbol on the specified line of the MyGDT
                |             drawing GDT
                |
                |              MyGDT.GetToleranceType(iRowNumber, oGDTSymbol)

        :param int i_row_number:
        :rtype: int
        """

        self.release_check(
            self.application.system_configuration.release,
            28,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return self.drawing_gdt.GetToleranceType(i_row_number)

    def set_tolerance_type(self, i_row_number: int, i_gdt_symbol: int) -> None:
        """

        Introduced in V5-6R2018.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2024-08-20 16:04:57.203445)
                | Sub SetToleranceType(long iRowNumber,long iGDTSymbol)
                |     Sets the symbol used in the row of the GDT.
                |
                |     Parameters:
                |
                |         iRowNumber
                |             The number of the row analyse. If the row doesn't exist, it will be
                |             created
                |         iGDTSymbol
                |             The symbol to use in this row.
                |
                |     See also:
                |         CATIADrawingGDT::GetToleranceType
                |         This example sets a symbol on a specified line of the MyGDT drawing
                |         GDT
                |
                |          MyGDT.SetToleranceType(iRowNumber, iGDTSymbol)

        :param int i_row_number:
        :param int i_gdt_symbol:
        :rtype: None
        """

        self.release_check(
            self.application.system_configuration.release,
            28,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        return self.drawing_gdt.SetToleranceType(i_row_number, i_gdt_symbol)

    def __repr__(self):
        return f'DrawingGDT(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R31 on 2026-02-21 14:49:57.443389

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.

"""
import inspect

from pycatia.in_interfaces.workbench import Workbench


class ShapeDesignWorkbench(Workbench):
    """

    Introduced in V5-6R2022.

        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2026-02-21 14:49:57.443389)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     InfInterfaces.Workbench
                |                         ShapeDesignWorkbench

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.release_check(
            self.application.system_configuration.release,
            32,
            f'{self.__class__.__name__}.{inspect.stack()[0][3]}',
        )

        self.com_object = com_object

    def __repr__(self):
        return f'ShapeDesignWorkbench(name="{self.name}")'
